-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1310) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1310.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- Add_Org_Type_Ora.sql
-- #########################################################
-- #########################################################


create or replace procedure AddOrgType(New_ID$ integer, NewName$ VarChar2)
as
  cnt$ Number(10);
begin
  select count(ID) into cnt$ from Org_Type where Name = NewName$;

  if cnt$ > 0 then
    Update Org_Type ev set
       ev.ID = New_ID$
    where (ev.Name = NewName$);
  else
    insert into Org_Type(ID, Name) values (New_ID$, NewName$);
  end if;  
end;
/

call AddOrgType(30200, '      ()')
/

drop procedure AddOrgType
/

commit work
/



-- #########################################################
-- #########################################################
-- UpdFilter_13.20.sql
-- #########################################################
-- #########################################################


CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

CALL DOCLOCK_IMPORT('   ',0,200,1,0,11,0,'',0,1,'    ,  ,   - \      .',0,'        ',null,'(([960110035] between 010800 and 011199)
([960110021]=("_.",.[20011008])))
([960110035] = 30200)',1) ;

CALL DOCLOCK_IMPORT('   ',0,201,0,0,11,0,'((32,30,3) = 0)  ((32,30,3) = 4)',0,1,'  ()  ,               ',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 201, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,0,20110015,1) ;

CALL DOCLOCK_IMPORT('     ',0,201,0,0,11,0,'(((32,30,3) = 0)  ((32,30,3) = 4))',0,1,'  () ,       , ,       ',0,'  .    , ,       ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 201, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('     ',201,0,20110015,1) ;

CALL DOCLOCK_IMPORT('   ',0,201,1,0,11,0,'',0,1,'             .       \',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 201, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',201,1,20111019,1) ;

CALL DOCLOCK_IMPORT('   ',0,202,0,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 202, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',202,0,20210039,1) ;

CALL DOCLOCK_IMPORT('   ',0,202,1,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 202, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',202,1,20211038,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,0,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,0,20310039,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,1,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,1,20311038,1) ;

CALL DOCLOCK_IMPORT('   ',0,204,0,0,11,0,'',0,1,'    .    () ,       ,         01.08.00  01.11.99,  01.02.00  01.03.99       03.02.00',0,'  .    ,  () , (),  ,   ,      ',null,'([960110035] between 10800 and 11199)([960110035] between 10200 and 10399)([960110035] = 30200)',1) ;

CALL DOCLOCK_IMPORT('     ',0,206,0,0,11,0,'(((32,30,3) = 0)  ((32,30,3) = 3))',0,1,'  () ,       , ,       ',0,'  .    , ,       ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 206, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('     ',206,0,20610040,1) ;

CALL DOCLOCK_IMPORT('   ',0,206,0,0,11,0,'((32,30,3) = 0)  ((32,30,3) = 3)',0,1,'  ()  ,               ',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 206, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,0,20610040,1) ;

CALL DOCLOCK_IMPORT('   ',0,206,1,0,11,0,'',0,1,'             .       \',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 206, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',206,1,20611039,1) ;

CALL DOCLOCK_IMPORT('   ',0,213,1,0,11,0,'',0,3,'    01.01. - 01.03.',0,'    (01.01.),  (01.02. - 01.03.)       (03.02.00)',null,'([960110035] between 10100 and 10399)([960110035] = 30200)',2) ;

CALL DOCLOCK_IMPORT('   ',0,323,1,0,11,0,'',0,1,'    ,  ,   - \      .',0,'        ',null,'(([960110035] between 010800 and 011199)
([960110021]=("_.",.[32311012])))
([960110035] = 30200)',1) ;

CALL DOCLOCK_IMPORT('   ',0,324,1,0,11,0,'',0,1,'    ,  ,   - \      .',0,'        ',null,'(([960110035] between 010800 and 011199)
([960110021]=("_.",.[32411026])))
([960110035] = 30200)',1) ;

CALL DOCLOCK_IMPORT('   ',0,1901,0,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1901, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1901,0,190110057,1) ;

CALL DOCLOCK_IMPORT('   ',0,1902,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1902, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1902,0,190210043,1) ;

CALL DOCLOCK_IMPORT('   ',0,1902,1,0,11,0,'',0,1,'   ',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1902, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1902,1,190211042,1) ;

CALL DOCLOCK_IMPORT('   ',0,1903,0,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1903, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1903,0,190310042,1) ;

CALL DOCLOCK_IMPORT('   ',0,1903,1,0,11,0,'',0,3,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1903, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1903,1,190311041,1) ;

CALL DOCLOCK_IMPORT('   ',0,1906,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1906, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1906,0,190610043,1) ;

CALL DOCLOCK_IMPORT('   ',0,1906,1,0,11,0,'',0,1,'   ',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 1906, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',1906,1,190611042,1) ;

CALL DOCLOCK_IMPORT('   ',0,2201,0,0,11,0,'',0,3,'     ,   ',0,'  .    , , ,      ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2201, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',2201,0,220110069,1) ;

CALL DOCLOCK_IMPORT('   ',0,2201,1,0,11,0,'',0,3,'             .',0,'  .           ',null,'([960110035] > 0  [960110035] < 20000)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 2201, 1, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('   ',2201,1,220111070,1) ;

CALL DOCLOCK_IMPORT(' ',0,9903,0,0,11,0,'([990310057] between 10000 and 19999)',0,3,'  ().   (, ) ()    , ,       ',0,'     ().  ()  ()    , ,       ',null,'(([960110035]>=10100)([960110035]<10500)(.[990310069]<>[960110033]))  
((.[990310057]>=10100)(.[990310057]<10500)(.[990310069]=[960110033])) 
([960110035] = 30200)  (.[990310057] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE(' ', 9903, 0, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD(' ',9903,0,990310084,1) ;

CALL DOCLOCK_IMPORT('  ',0,9903,2,0,11,0,'',0,3,'  .     /, ()      ',0,'      .      /      ',null,'([960110035] between 10800 and 11099)([960110035] = 30200)',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 9903, 2, 0, 1) ;

CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,2,990312098,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

COMMIT WORK
/


-- #########################################################
-- #########################################################
-- UpdateEnumValue_ServiceAcc.sql
-- #########################################################
-- #########################################################


CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CALL ENUMVALUES_IMPORT('','',5) ;

DROP PROCEDURE ENUMVALUES_IMPORT
/

COMMIT WORK
/


-- #########################################################
-- #########################################################
-- UpdDocFields_13.20.00.sql
-- #########################################################
-- #########################################################


--  : 131000 - 132000.     13.10.2020 09:05:07.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(216, 280, '   ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL ImportDocType(217, 281, '   ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(21600, 216, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 280) ;

CALL ImportDocCLS(21601, 216, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 280) ;

CALL ImportDocCLS(21700, 217, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 281) ;

CALL ImportDocCLS(21701, 217, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

CALL ImportDocCLS(21702, 217, '2', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM STOREDATTRIBUTESDETAIL
  WHERE (ATTRIBUTEFIELD = ID$) or (CONTAINERFIELD = ID$);  

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--    , (0)
CALL ImportField(21600054, '  ', 'IsInBudget', '  ', 'IsInBudget', 0, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21600055, ' ', 'IsVised', ' ', 'IsVised', 0, 216, 0, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(21610001, '()', 'CREATERUSER', '()', 'CREATERUSER_Cpt', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610003, '  ()', 'CREATEDATE', '  ()', ' ', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610004, ' ()', 'UPDATERUSER', ' ()', ' ', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610005, ' ', 'Id', ' ', 'Id', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610006, ' ', 'Note1', ' ', 'Note1', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610007, '', 'BudgetRef', '', 'BudgetRef', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610008, '', 'Variant', '', 'Variant', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610009, '', 'Number', '', 'Number', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610010, ' ', 'DateInput', ' ', 'DateInput', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610011, '  ()', 'OrgRef', '  ()', 'DestOrgRef', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610012, '  ', 'RejectCls', '  ', 'RejectCls', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610013, '  ()', 'RejectCause', '  ()', 'RejectCause', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610014, ' ', 'CryptoStatus', ' ', 'CryptoStatus', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610015, '', 'DocStateRef', '', 'DocStateRef', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610016, '  ', 'SenderId', '  ', 'SenderId', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610017, '\  ', 'FacialAccCls', '\  ', 'FacialAccCls', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21610018, '  ', 'SenderRecordID', '  ', 'SenderRecordID', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610019, ' ', 'ProgIndex', ' ', 'ProgIndex', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610056, ' ', 'PlanDocType', ' ', 'PlanDocType', 2, 216, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21610057, ' ', 'Dat', ' ', 'Dat', 2, 216, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611002, '()', 'CREATERUSER', '()', 'CREATERUSER_Det', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611020, ' ', 'ClsType', ' ', 'ClsType', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611021, ' ', 'SUMMAYEAR1', ' ', 'SUMMAYEAR1', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611022, '', 'TreeOwner0', ' ()', ' ', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611023, ' 1', 'Quarter1', ' 1', 'Quarter1', 2, 216, 1, 0, '1', 0, null, 0, 0, '') ;

CALL ImportField(21611024, ' 2', 'Quarter2', ' 2', 'Quarter2', 2, 216, 1, 0, '2', 0, null, 0, 0, '') ;

CALL ImportField(21611025, ' 3', 'Quarter3', ' 3', 'Quarter3', 2, 216, 1, 0, '3', 0, null, 0, 0, '') ;

CALL ImportField(21611026, ' 4', 'Quarter4', ' 4', 'Quarter4', 2, 216, 1, 0, '4', 0, null, 0, 0, '') ;

CALL ImportField(21611027, '', 'Month01', '', 'Month01', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611028, '', 'Month02', '', 'Month02', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611029, '', 'Month03', '', 'Month03', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611030, '', 'Month04', '', 'Month04', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611031, '', 'Month05', '', 'Month05', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611032, '', 'Month06', '', 'Month06', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611033, '', 'Month07', '', 'Month07', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611034, '', 'Month08', '', 'Month08', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611035, '', 'Month09', '', 'Month09', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611036, '', 'Month10', '', 'Month10', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611037, '', 'Month11', '', 'Month11', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611038, '', 'Month12', '', 'Month12', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611039, '  ', 'SenderRecordId', '  ', 'SenderRecordId', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611040, '  ', 'SenderId', '  ', 'SenderId', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611041, ' ', 'RecordIndex', ' ', 'RecordIndex', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611042, ' ', 'FacialAcc_Cls', ' ', 'DestFacialAccCls', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611043, '', 'KVSR', '()', 'DestKvsrKey', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611044, '()', 'KVSRCode', '()', 'DestKvsr', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611045, '()', 'KFSR', '()', 'DestKfsr', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611046, '', 'KVR', '()', 'DestKvrKey', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611047, '()', 'KVRCode', '()', 'DestKvr', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611048, '', 'KCSR', '()', 'DestKcsrKey', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611049, '()', 'KCSRCode', '()', 'DestKcsr', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611050, '', 'Org_Ref', '', 'Org_Ref_Det', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611051, ' ()', 'IFS_DescriptionCode', ' ()', 'IFS_DescriptionCode', 2, 216, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21611052, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611053, '()', 'IFSAGCode', '()', 'IFS_KESRCode', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611057, '', 'KD', '', 'KD', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611058, ' .  . . ()', 'IFS', ' ', 'IFS', 2, 216, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21611059, '', 'Note', '', 'Note', 2, 216, 1, 1, '', 0, 17431, 0, 0, '') ;

CALL ImportField(21610058, '.  ', 'StoredContent', '.  ', 'StoredContent', 2, 216, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21611060, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 2, 216, 1, 0, '', 0, null, 0, 2, '') ;

--    , (0)
CALL ImportField(21700018, '  ', 'IsInBudget', '  ', 'IsInBudget', 0, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21700019, ' ', 'IsVised', ' ', 'IsVised', 0, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21700020, ' ', 'DocSuspended', ' ', 'DocSuspended', 0, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21701036, ' .  . .', 'IFSCode', ' ()', 'IFS_FinSourceValue', 0, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21701037, '()', 'INN', '()', 'DestOrgInn', 0, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21701038, '()', 'INN20', '()', 'DestOrgKPP', 0, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21701052, '()', 'NAME', '()', 'DestOrgNAME', 0, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21701053, '', 'OrgParent', ' ', ' ', 0, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21702063, ' .  . .', 'IFSCode', ' ()', ' ', 0, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21702080, '', 'OrgParent', ' ', ' ', 0, 217, 2, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(21711032, ' ()', 'IFS_DescriptionCode', ' ()', 'IFS_DescriptionCode', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711033, '', 'IFS_FinSourceValue', '   ', 'IFS_FinSourceValue', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711034, '()', 'IFS_KVSRCode', '()', 'IFS_KVSRCode', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711035, '()', 'IFSAGCode', '()', 'IFS_KESRCode', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711039, '()', 'INN', '()', 'DestFacialAccClsOrgINN', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711040, '()', 'INN20', '()', 'DestFacialAccClsOrgKPP', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711043, '()', 'KDAGCode', '()', 'KDKESRCode', 1, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711044, '()', 'KDKVSRCode', '()', 'KDKVSRCode', 1, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711045, ' ', 'KDValue', ' ', 'KDValue', 1, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711054, '()', 'NAME', '()', 'DestFacialAccClsOrgName', 1, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711055, '', 'OrgNameAndAcc', '', ' ', 1, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712060, ' ()', 'IFS_DescriptionCode', ' ()', ' ', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712061, '()', 'IFS_KVSRCode', '()', ' ', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712062, '()', 'IFSAGCode', '()', ' ', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712069, '()', 'KDAGCode', '()', 'KDKESRCode', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712070, ' ()', 'KDKVSRCode', ' ()', 'KDKVSRCode', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712071, ' ', 'KDValue', ' ', 'KDValue', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712079, '', 'OrgNameAndAcc', '', ' ', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712081, ' ()', 'ProgramCode', ' ()', 'ProgramCode', 1, 217, 2, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(21710001, '  ()', 'CREATEDATE', '  ()', ' ', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710002, '()', 'CREATERUSER', '()', 'CREATERUSER_CPT', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710003, '', 'BudgetRef', '', 'BudgetRef', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710004, ' ', 'ClsType', ' ', 'ClsType', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710005, ' ', 'Dat', ' ', 'Dat', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710006, ' ', 'DateInput', ' ', 'DateInput', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710007, '', 'DocStateRef', ' ', 'DocStateRef', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710008, '\  ', 'FacialAccCls', '\  ', 'FacialAccCls', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710009, ' ', 'ID', ' ', 'ID', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710010, ' ', 'Note1', ' ', 'Note1', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710011, ' ', 'Number', ' ', 'Number', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710012, ' ', 'OrgRef', ' ', 'DestOrgRef', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710013, ' ', 'OrgName', ' ', 'DestOrgName', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710014, ' ', 'ProgIndex', ' ', 'ProgIndex', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710015, '  ()', 'RejectCause', '  ()', 'RejectCause', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710016, '  ', 'RejectCls', '  ', 'RejectCls', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710017, '', 'Variant', '', 'Variant', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710021, ' ()', 'UPDATERUSER', ' ()', ' ', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710022, '  ()', 'UPDATEDATE', '  ()', ' ', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710023, '', 'KPPeriod', '', 'KPPeriod', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710024, '  ', 'SenderId', '  ', 'SenderId', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710025, '  ', 'SenderRecordID', '  ', 'SenderRecordID', 2, 217, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21710082, ' ', 'PlanDocType', ' ', 'PlanDocType', 2, 217, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711026, ' ', 'ClsType', ' ', 'ClsType', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711027, '', 'DayPlan', '', 'DayPlan', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711028, '', 'DayPlanSumma', '', 'DayPlanSumma', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711029, ' ', 'FacialAcc_Cls', ' ', 'DestFacialAccCls', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711030, ' ', 'Id', ' ', 'Id', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711031, ' .  . . ()', 'IFS', '()', 'IFS', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711041, '()', 'KCSRCode', '()', 'DestKcsr', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711042, '', 'KD', '', 'KD', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711046, '()', 'KESRCODE', '()', 'DestKesr', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711047, '()', 'KFSR', '()', 'DestKfsr', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711048, '()', 'KVRCode', '()', 'DestKvr', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711049, '()', 'KVSRCode', '()', 'DestKvsr', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21711050, '  ', 'RecordIndex', '  ', 'RecordIndex', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711051, '', 'TreeOwner0', '', ' ', 2, 217, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21712056, ' ', 'ClsType', ' ', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712057, ' ', 'FacialAcc_Cls', ' ', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712058, '/ ', 'FacialCode', '/ ', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712059, ' .  . . ()', 'IFS', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712064, '()', 'INN', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712065, '()', 'INN20', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712066, '', 'KCSR', ' ()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712067, '()', 'KCSRCode', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712068, '', 'KD', '', 'KD', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712072, '', 'KESR', ' ()', 'DestKesrKey', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712073, '()', 'KESRCODE', '()', 'DestKesr', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712074, '()', 'KFSR', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712075, '', 'KVR', ' ()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712076, '()', 'KVRCode', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712077, '', 'KVSR', ' ()', 'DestKvsrKey', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712078, '()', 'KVSRCode', '()', ' ', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21711052, '', 'Note', '', 'Note', 2, 217, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21712082, '', 'Note', '', 'Note', 2, 217, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21710083, '.  ', 'StoredContent', '.  ', 'StoredContent', 2, 217, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21711053, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 2, 217, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21712083, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 2, 217, 2, 0, '', 0, null, 0, 2, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/




CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_IMPORT(990238700,'.BUDGETREF()->.ID',987810006,21610007,0,0) ;

CALL STATICLINK_IMPORT(960205100,'.ORGREF()->.ID',960110033,21610011,0,0) ;

CALL STATICLINK_IMPORT(990238800,'.REJECTCLS()->.ID',985010005,21610012,0,0) ;

CALL STATICLINK_IMPORT(980233100,'.FACIALACCCLS()->.ID',984110021,21610017,0,0) ;

CALL STATICLINK_IMPORT(20203100,'.1.RECORDINDEX()->.ID()',21610005,21611041,0,2) ;

CALL STATICLINK_IMPORT(980233000,'.1.FACIALACC_CLS()->.ID',984110021,21611042,0,0) ;

CALL STATICLINK_IMPORT(980232700,'.1.KVSR()->.ID',980310002,21611043,0,0) ;

CALL STATICLINK_IMPORT(980232800,'.1.KFSR()->.ID',980210004,21611045,0,0) ;

CALL STATICLINK_IMPORT(980232600,'.1.KVR()->.ID',980410002,21611046,0,0) ;

CALL STATICLINK_IMPORT(980232900,'.1.KCSR()->.ID',980510002,21611048,0,0) ;

CALL STATICLINK_IMPORT(960205000,'.1.ORG_REF()->.ID',960110033,21611050,0,0) ;

CALL STATICLINK_IMPORT(990239100,'.BUDGETREF()->.ID',987810006,21710003,0,0) ;

CALL STATICLINK_IMPORT(980233400,'.FACIALACCCLS()->.ID',984110021,21710008,0,0) ;

CALL STATICLINK_IMPORT(960205200,'.ORGREF()->.ID',960110033,21710012,0,0) ;

CALL STATICLINK_IMPORT(990239000,'.REJECTCLS()->.ID',985010005,21710016,0,0) ;

CALL STATICLINK_IMPORT(980233300,'.1.KD()->.ID',980910006,21711042,0,0) ;

CALL STATICLINK_IMPORT(20203200,'.1.RECORDINDEX()->.ID()',21610005,21711050,0,2) ;

CALL STATICLINK_IMPORT(980233500,'.2.FACIALACC_CLS()->.ID',984110021,21712057,0,0) ;

CALL STATICLINK_IMPORT(990238600,'.PLANDOCTYPE()->.ID',986410002,21610056,0,0) ;

CALL STATICLINK_IMPORT(990239200,'.PLANDOCTYPE()->.ID',988410002,21710082,0,0) ;

CALL STATICLINK_IMPORT(980233200,'.1.KD()->.ID',980910006,21611057,0,0) ;

CALL STATICLINK_IMPORT(990238900,'.1.IFS()->.ID',985210008,21611058,0,0) ;

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('','  ',0) ;

CALL ENUMVALUES_IMPORT('','    ',1) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

CALL DOCLOCK_IMPORT(' ',65536,216,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 216, -1, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,-1,21610013,2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,-1,21610012,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,-1,21610057,2) ;

CALL DOCLOCK_IMPORT('  ',65536,216,-1,0,7,0,'',1,1,'   .   ,   .           .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 216, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ,   ',65540,216,-1,0,4,2,'',0,2,'     ,   .       . ,     .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 216, -1, 1, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610007,1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611051,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611050,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611049,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611047,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611045,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611044,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611042,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611038,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611037,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611036,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611035,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611034,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611033,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611032,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611031,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611030,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611029,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611028,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611027,1) ;

--  " 4"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611026,1) ;

--  " 3"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611025,1) ;

--  " 2"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611024,1) ;

--  " 1"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611023,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611022,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21611021,1) ;

--  "\  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610017,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610013,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610012,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610011,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610010,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610009,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610008,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',216,-1,21610057,1) ;

CALL DOCLOCK_IMPORT(' .    ',131072,216,-1,0,7,0,'[21610006] = "1"',0,1,'     ',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' .    ', 216, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ',65540,216,0,0,4,2,'',0,1,'  .       ',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 216, 0, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,0,21610013,2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,0,21610012,2) ;

CALL DOCLOCK_IMPORT(' ',65540,216,0,0,4,2,'[21610056]<200',0,1,'  .        .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 216, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,0,21610057,2) ;

CALL DOCLOCK_IMPORT(' ',65540,216,0,0,4,2,'[21610056]>=200',0,1,'  .       .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 216, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',216,0,21610057,2) ;

CALL DOCLOCK_IMPORT('  ',65536,217,-1,0,7,0,'',1,1,'   .   ,   .           .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 217, -1, 0, 2) ;

CALL DOCLOCK_IMPORT(' ',65536,217,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 217, -1, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,-1,21710005,2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,-1,21710015,2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,-1,21710016,2) ;

CALL DOCLOCK_IMPORT(' ,   ',65540,217,-1,0,4,2,'',0,2,'     ,   .       . ,     .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 217, -1, 1, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',217,-1,21710013,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',217,-1,21710016,1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',217,-1,21710015,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',217,-1,21710011,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',217,-1,21710006,1) ;

CALL DOCLOCK_IMPORT(' ',65540,217,0,0,4,2,'',0,1,'  .       ',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 217, 0, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,0,21710015,2) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,0,21710016,2) ;

CALL DOCLOCK_IMPORT(' ',65540,217,0,0,4,2,'[21710082]<200',0,1,'  .        .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 217, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,0,21710005,2) ;

CALL DOCLOCK_IMPORT(' ',65540,217,0,0,4,2,'[21710082]>=200',0,1,'  .       .',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE(' ', 217, 0, 0, 2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',217,0,21710005,2) ;

CALL DOCLOCK_IMPORT('  ',32768,9903,0,0,5,0,'([990310083] is not null) and (([990310057] < 30200) or ([990310057] > 30299))',0,3,'  ,       .',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 9903, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310057,1) ;

--  "E-mail "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310018,1) ;

--  " Web-"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310019,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310076,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310020,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310060,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310059,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310004,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',9903,0,990310021,1) ;

CALL DOCLOCK_IMPORT('  ',0,216,-1,0,15,1,'',0,1,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 216, -1, 0, 2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',216,-1,21611060,2) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',216,-1,21610058,2) ;

CALL DOCLOCK_IMPORT('  ',0,216,-1,0,12,0,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 216, -1, 0, 2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',216,-1,21611060,2) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',216,-1,21610058,2) ;

CALL DOCLOCK_IMPORT('  ',0,217,-1,0,12,0,'',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 217, -1, 0, 2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21712083,2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21711053,2) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21710083,2) ;

CALL DOCLOCK_IMPORT('  ',0,217,-1,0,15,1,'',0,1,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 217, -1, 0, 2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21712083,2) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21711053,2) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',217,-1,21710083,2) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL SELECTIONS_IMPORT(35357, 1, 'CLSCORRESPONDENTS', '', 0, 0, 'CLSCORRESPONDENTS', 'CLSCORRESPONDENTS', 0, 0, 0, 2, '', 1, 1, 3600, -1, null, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(45358, 2, '_', '', 0, 0, '', '', 0, 0, 0, 2, '', 1, 1, 600, null, 5, '', '', null, 0) ;

CALL SELECTIONSDETAIL_IMPORT(45359, 45358, 35357, 'CLSCORRESPONDENTS', 0, 0, 1, '', 0, '', 0) ;

-- _
CALL FIELDSINFO_IMPORT(45372, 0, 2, 35361, 45358, 45359, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'ID', '') ;

CALL FIELDSINFO_IMPORT(45374, 0, 2, 35359, 45358, 45359, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CREATEDATE', '') ;

CALL FIELDSINFO_IMPORT(45376, 0, 2, 35360, 45358, 45359, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CREATERUSER', '') ;

CALL FIELDSINFO_IMPORT(45377, 0, 2, 35362, 45358, 45359, 'KESR', 3, 0, 0, '', '', 11, '', '', '', 0, 0, null, 1, 16871, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, '', 'KESR', '') ;

CALL FIELDSINFO_IMPORT(45378, 0, 2, 35363, 45358, 45359, 'KVR', 3, 0, 0, '', '', 11, '', '', '', 0, 0, null, 1, 16864, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, '', 'KVR', '') ;

CALL FIELDSINFO_IMPORT(45379, 0, 2, 35364, 45358, 45359, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', 'UPDATEDATE', '') ;

CALL FIELDSINFO_IMPORT(45380, 0, 2, 35365, 45358, 45359, 'UPDATERUSER', 1, 0, 30, ' ', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'UPDATERUSER', '') ;

CALL FIELDSINFO_IMPORT(45381, 0, 2, 39250, 45358, 45359, 'KFSR', 3, 0, 0, '', '', 0, '', '', '', 0, 0, null, 1, 16844, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KFSR', '') ;

CALL FIELDSINFO_IMPORT(45382, 0, 2, 39251, 45358, 45359, 'CORRTYPE', 3, 0, 0, ' ', '', 0, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CORRTYPE', '') ;

CALL FIELDSINFO_IMPORT(45383, 0, 2, 39252, 45358, 45359, 'CORRBEL', 3, 0, 0, ' ', '', 0, '', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'CORRBEL', '') ;

CALL FIELDSINFO_IMPORT(45384, 1, 2, null, 45358, null, 'KVRCODE', 1, 0, 3, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KVRCODE', '') ;

CALL FIELDSINFO_IMPORT(45385, 1, 2, null, 45358, null, 'KESRCODE', 1, 0, 3, ' ', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'KESRCODE', '') ;

--  
CALL SELECTIONEVENTS_IMPORT(45358, 45358, 3, '') ;

DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

COMMIT WORK
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (3375, 131000, 132000, TO_DATE('13.10.2020 9:5:7', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 02.13, 02.14, 02.15, 02.16, 02.17, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 18.18, 18.19, 18.20, 18.21, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 44.01, 44.03, 47.01, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 53.03, 53.04, 53.05, 53.06, 54.01, 54.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 97.09, 97.10, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.98, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30, 99.31, 99.32', 'MCHEKUNOV/mchekunov', TO_DATE('13.10.2020 9:5:42', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- Add_ConstForecast.sql
-- #########################################################
-- #########################################################

CALL AddIntConst(1005, 280, 1, '')
/
CALL AddIntConst(1006, 280, 2, '')
/
CALL AddIntConst(1005, 281, 1, '')
/
CALL AddIntConst(1006, 281, 2, '')
/
commit work
/


-- #########################################################
-- #########################################################
-- UpdateRemoteDocData.sql
-- #########################################################
-- #########################################################

/* 
         RemoteDocument
          .
      .
*/
/*         ,  ,  */
CREATE OR REPLACE procedure UpdateRemoteDocument(ID$ NUMBER,Name$ VARCHAR2)
AS
  CNT$1 NUMBER(10);
BEGIN
  SELECT COUNT(ID ) INTO CNT$1
  from RemoteDocument where (ID = ID$) AND (ROWNUM = 1);
  if (not (CNT$1<> 0)) then
    insert into RemoteDocument(ID, Name) values (ID$, Name$);
      
  else
    update RemoteDocument set 
    Name = Name$ 
     
    where 
    ID = ID$;
  END IF;
END;
/
/* !!!      50  !!! */
CALL UpdateRemoteDocument(280 , '   ')
/
CALL UpdateRemoteDocument(281 , '   ')
/
drop procedure UpdateRemoteDocument 
/
commit work
/





-- #########################################################
-- #########################################################
-- alter_OrgAccounts_SKP.sql
-- #########################################################
-- #########################################################

/* 
       -      03.02.00 () 
          ,     
  ,    
*/
-- ALTER TRIGGER TR_ORG_ACCOUNTS_BI
CREATE OR REPLACE TRIGGER TR_ORG_ACCOUNTS_II
  INSTEAD OF INSERT
  ON ORG_ACCOUNTS
  FOR EACH ROW
DECLARE
  new$ID ORG_ACCOUNTS.ID%TYPE := :NEW.ID;
  new$ORG_REF ORG_ACCOUNTS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$BANK_REF ORG_ACCOUNTS.BANK_REF%TYPE := :NEW.BANK_REF;
  new$ACC ORG_ACCOUNTS.ACC%TYPE := :NEW.ACC;
  new$ACC_CLS ORG_ACCOUNTS.ACC_CLS%TYPE := :NEW.ACC_CLS;
  new$FINTYPE ORG_ACCOUNTS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$CREATERUSER ORG_ACCOUNTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORG_ACCOUNTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORG_ACCOUNTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORG_ACCOUNTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CLOSED ORG_ACCOUNTS.CLOSED%TYPE := :NEW.CLOSED;
  new$ACCDEFAULT ORG_ACCOUNTS.ACCDEFAULT%TYPE := :NEW.ACCDEFAULT;
  new$BANKDEPNUMBER ORG_ACCOUNTS.BANKDEPNUMBER%TYPE := :NEW.BANKDEPNUMBER;
  new$FACIALCODE ORG_ACCOUNTS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$SERVICE_ORG_REF ORG_ACCOUNTS.SERVICE_ORG_REF%TYPE := :NEW.SERVICE_ORG_REF;
  new$ACOMMENT ORG_ACCOUNTS.ACOMMENT%TYPE := :NEW.ACOMMENT;
  new$ISDEFAULT ORG_ACCOUNTS.ISDEFAULT%TYPE := :NEW.ISDEFAULT;
  new$RVERSION ORG_ACCOUNTS.RVERSION%TYPE := :NEW.RVERSION;
  new$SERVICE_ACC_REF ORG_ACCOUNTS.SERVICE_ACC_REF%TYPE := :NEW.SERVICE_ACC_REF;
  new$CLOSECODE ORG_ACCOUNTS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$SERVICEACC ORG_ACCOUNTS.SERVICEACC%TYPE := :NEW.SERVICEACC;
  new$FACIALACC_CLS ORG_ACCOUNTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$DATEOPEN ORG_ACCOUNTS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$DATECLOSE ORG_ACCOUNTS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$EXTID ORG_ACCOUNTS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORG_ACCOUNTS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORG_ACCOUNTS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
--
  ADate$ NUMBER;
  AClosed1$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ORG_ACCOUNTS_BI)
-- Version 13.20.00.1
-- - - - - - - - - - - - -

  if (new$Org_Ref = 0) then 
    RaiseException('ex_CantAddUnknownOrgAcc');
  END IF;
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$ACC_CLS is null) then 
    new$ACC_CLS:= 0;
  END IF;
  if (new$AccDefault is null) then 
    new$AccDefault:= 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType:= 0;
  END IF;
  if ((new$AComment is null) or (new$AComment  is null)) then 
    new$AComment := new$Acc;
  END IF;
  if ((new$IsDefault is not Null) and (new$IsDefault <> 0)) then
    update ORG_ACCOUNTS set
    IsDefault = 0
    where ORG_REF = new$ORG_REF
    and IsDefault is not Null
    and IsDefault <> 0;
  END IF;
  if ((new$SERVICE_ORG_REF is null)and(new$SERVICE_ACC_REF is not null)) then
    BEGIN
      select
      oa.Org_Ref
      into
      new$SERVICE_ORG_REF    from
      org_accounts oa
      where
      (oa.id = new$SERVICE_ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*               */
  if (new$ServiceAcc is null) then
    BEGIN
      select SERVICETYPE into new$ServiceAcc from ACC_CLS where (id = new$ACC_CLS) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*       NULL,   0() */
  if (new$ServiceAcc is null) then
    new$ServiceAcc := 0;
    if (new$SERVICE_ORG_REF is not null) then
      BEGIN
        select
        o.Org_Type
        into vOrgType1$      from
        Organizations o
        where
        (o.id = new$SERVICE_ORG_REF)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /* 01.01.xx  -   */
      if ((vOrgType1$  > 10099)and(vOrgType1$  < 10200)) then
        new$ServiceAcc := 3;
             
      else
        /* 03.02.xx     -   */
        if ((vOrgType1$  > 30199)and(vOrgType1$  < 30300)) then
          new$ServiceAcc := 1;
               
        else
          /* 04.xx.xx  -   */
          if ((vOrgType1$  > 39999)and(vOrgType1$  < 50000)) then
            new$ServiceAcc := 1;
          END IF;
        END IF;   
      END IF; 
    END IF;
  END IF;
  /*      . .   .  ,   ,
       ,     .  */
  if ((new$Service_Acc_Ref is not null) and (new$ServiceAcc <> 0)) then
    BEGIN
      select
      Bank_Ref, Acc
      into new$Bank_Ref, new$FacialCode    from
      Org_Accounts
      where
      new$Service_Acc_Ref = Id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_ORG_ACCOUNTS_BI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$CloseCode is null) then 
    new$CloseCode := 0;
  END IF;
  /*     /,   -      */
  if (new$Org_Ref is not null) then
    BEGIN
      select DateClose into ADate$ from organizations where Id = new$Org_ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (ADate$  is not null) then 
      new$Closed := 1;
      new$DateClose := ADate$;
      new$CloseCode := 10; /*   */
      
    END IF;
  END IF;
  if (new$Bank_Ref is not null) then
    BEGIN
      select DateClose into ADate$ from Banks where Id = new$Bank_ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (ADate$  is not null) then 
      new$Closed := 1;
      new$DateClose := ADate$;
      new$CloseCode := new$CloseCode + 1000; /*   */
      
    END IF;
  END IF;
  if (new$Service_Acc_Ref is not null) then
    BEGIN
      select Closed, DateClose into AClosed1$, ADate$ from Org_Accounts where Id = new$Service_Acc_Ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (AClosed1$  is not null) then 
      new$Closed := 1;
      new$DateClose := ADate$;
      new$CloseCode := new$CloseCode + 100; /*    */
      
    END IF;  /*   facialacc_cls   -  -      / */
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ORG_ACCOUNTS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_ORG_ACCOUNTS (
    ID,
    ORG_REF,
    BANK_REF,
    ACC,
    ACC_CLS,
    FINTYPE,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    CLOSED,
    ACCDEFAULT,
    BANKDEPNUMBER,
    FACIALCODE,
    SERVICE_ORG_REF,
    ACOMMENT,
    ISDEFAULT,
    RVERSION,
    SERVICE_ACC_REF,
    CLOSECODE,
    SERVICEACC,
    FACIALACC_CLS,
    DATEOPEN,
    DATECLOSE,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE
  ) VALUES (
    new$ID,
    new$ORG_REF,
    new$BANK_REF,
    new$ACC,
    new$ACC_CLS,
    new$FINTYPE,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$CLOSED,
    new$ACCDEFAULT,
    new$BANKDEPNUMBER,
    new$FACIALCODE,
    new$SERVICE_ORG_REF,
    new$ACOMMENT,
    new$ISDEFAULT,
    new$RVERSION,
    new$SERVICE_ACC_REF,
    new$CLOSECODE,
    new$SERVICEACC,
    new$FACIALACC_CLS,
    new$DATEOPEN,
    new$DATECLOSE,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_ORG_ACCOUNTS_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 21) and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER TR_ORG_ACCOUNTS_BU
CREATE OR REPLACE TRIGGER TR_ORG_ACCOUNTS_IU
  INSTEAD OF UPDATE
  ON ORG_ACCOUNTS
  FOR EACH ROW
DECLARE
  new$ID ORG_ACCOUNTS.ID%TYPE := :NEW.ID;
  new$ORG_REF ORG_ACCOUNTS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$BANK_REF ORG_ACCOUNTS.BANK_REF%TYPE := :NEW.BANK_REF;
  new$ACC ORG_ACCOUNTS.ACC%TYPE := :NEW.ACC;
  new$ACC_CLS ORG_ACCOUNTS.ACC_CLS%TYPE := :NEW.ACC_CLS;
  new$FINTYPE ORG_ACCOUNTS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$CREATERUSER ORG_ACCOUNTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE ORG_ACCOUNTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE ORG_ACCOUNTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER ORG_ACCOUNTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$CLOSED ORG_ACCOUNTS.CLOSED%TYPE := :NEW.CLOSED;
  new$ACCDEFAULT ORG_ACCOUNTS.ACCDEFAULT%TYPE := :NEW.ACCDEFAULT;
  new$BANKDEPNUMBER ORG_ACCOUNTS.BANKDEPNUMBER%TYPE := :NEW.BANKDEPNUMBER;
  new$FACIALCODE ORG_ACCOUNTS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$SERVICE_ORG_REF ORG_ACCOUNTS.SERVICE_ORG_REF%TYPE := :NEW.SERVICE_ORG_REF;
  new$ACOMMENT ORG_ACCOUNTS.ACOMMENT%TYPE := :NEW.ACOMMENT;
  new$ISDEFAULT ORG_ACCOUNTS.ISDEFAULT%TYPE := :NEW.ISDEFAULT;
  new$RVERSION ORG_ACCOUNTS.RVERSION%TYPE := :NEW.RVERSION;
  new$SERVICE_ACC_REF ORG_ACCOUNTS.SERVICE_ACC_REF%TYPE := :NEW.SERVICE_ACC_REF;
  new$CLOSECODE ORG_ACCOUNTS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$SERVICEACC ORG_ACCOUNTS.SERVICEACC%TYPE := :NEW.SERVICEACC;
  new$FACIALACC_CLS ORG_ACCOUNTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$DATEOPEN ORG_ACCOUNTS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$DATECLOSE ORG_ACCOUNTS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$EXTID ORG_ACCOUNTS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER ORG_ACCOUNTS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE ORG_ACCOUNTS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
--
  ADate$ NUMBER;
  DiffCode1$ NUMBER(10);
  Code11$ NUMBER(10);
  Code21$ NUMBER(10);
  Code31$ NUMBER(10);
  Code41$ NUMBER(10);
  Code5$ NUMBER(10);
  AFlag1$ NUMBER(10);
  vOrgType2$ NUMBER(10);
  vOrgType$ NUMBER(10);
  vServiceAcc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ORG_ACCOUNTS_BU)
-- Version 13.20.00.1
-- - - - - - - - - - - - -

  if (new$ACC_CLS is null) then 
    new$ACC_CLS:= 0;
  END IF;
  if (new$AccDefault is null) then 
    new$AccDefault:= 0;
  END IF;
  if (new$FinType is null) then 
    new$FinType:= 0;
  END IF;
  if ((new$AComment is null) or (new$AComment  is null) 
  or (new$AComment = :old.AComment) and (:old.AComment = :old.Acc)) then
    new$AComment := new$Acc;
  END IF;
  if ((new$IsDefault is not Null) and (new$IsDefault <> 0)
  and ((:old.IsDefault is Null) or (:old.IsDefault = 0))) then
    update ORG_ACCOUNTS set
    IsDefault = 0
    where ORG_REF = new$ORG_REF
    and IsDefault is not Null
    and IsDefault <> 0;
  END IF;
  if ((new$SERVICE_ORG_REF is null)and(new$SERVICE_ACC_REF is not null)) then
    BEGIN
      select
      oa.Org_Ref
      into
      new$SERVICE_ORG_REF    from
      org_accounts oa
      where
      (oa.id = new$SERVICE_ACC_REF)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*               */
  if (new$ACC_CLS <> :old.ACC_CLS) then
    BEGIN
      select SERVICETYPE into vServiceAcc$ from ACC_CLS where (id = new$ACC_CLS) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*     ,    */
    if (vServiceAcc$ is not null) then
      new$ServiceAcc := vServiceAcc$;
     
    END IF;
  END IF;
  /*      ,       */
  if (:old.ServiceAcc is not null and new$ServiceAcc = 0 and :old.ServiceAcc <> new$ServiceAcc) then
    new$service_acc_ref := null;
    new$service_org_ref := null;
     
  END IF;
  /*       NULL,   0() */
  if (new$ServiceAcc is null) then
    new$ServiceAcc := 0;
    if (new$SERVICE_ORG_REF is not null) then
      BEGIN
        select
        o.Org_Type
        into vOrgType$      from
        Organizations o
        where
        (o.id = new$SERVICE_ORG_REF)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /* 01.01.xx  -   */
      if ((vOrgType$  > 10099)and(vOrgType$  < 10200)) then
        new$ServiceAcc := 3;
             
      else
        /* 03.02.xx     -   */
        if ((vOrgType$  > 30199)and(vOrgType$  < 30300)) then
          new$ServiceAcc := 1;
               
        else
          /* 04.xx.xx  -   */
          if ((vOrgType$  > 39999)and(vOrgType$  < 50000)) then
            new$ServiceAcc := 1;
          END IF;
        END IF;   
      END IF; 
    END IF;
  END IF;
  /*            */
  if (new$Acc <> :old.Acc) then
    update facialacc_cls set
    FACIALCODE = new$Acc
    where
    FCACCOUNT = new$id;
     
  END IF;
  /*      . .   .  ,   ,
       ,     .  */
  if ((new$Service_Acc_Ref is not null) and (new$ServiceAcc <> 0)
  and (new$Service_Acc_Ref <> :old.Service_Acc_Ref)) then
    BEGIN
      select
      Bank_Ref, Acc
      into new$Bank_Ref, new$FacialCode    from
      Org_Accounts
      where
      new$Service_Acc_Ref = Id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   */
  /*     ,        
       .  ,        */
  /*    ,          .  */
  if ((new$Bank_Ref <> :old.Bank_Ref) or (new$Acc <> :old.Acc)) then
    update Org_Accounts set
    Bank_Ref = new$Bank_Ref,
    FacialCode = new$Acc
    where
    (Service_Acc_Ref = new$ID) and
    (ID <> new$ID);
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_ORG_ACCOUNTS_BU_100)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$CloseCode is null) then
    new$CloseCode := 0;
  END IF;
  CloseOrgCls_Div(:old.CloseCode,Code11$, Code21$, Code31$, Code41$, Code5$);

  /* ??         */

  /*   ,        ,      */
  if ((new$Bank_ref <> :old.Bank_ref) and (Code41$ = 1)) then
    BEGIN
      select DateClose into ADate$ from Banks where ID = new$Bank_ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (ADate$ is null) then
      Code41$ := 0; /*    ,       . . */
      new$CloseCode := :old.CloseCode - 1000;

    else
      if (new$DateClose > ADate$) then
        new$DateClose := ADate$;
      END IF;
    END IF;
  END IF;

  /*    ,       . . -   */
  if ((new$Service_Acc_ref <> :old.Service_Acc_Ref) and (Code31$ = 1)) then
    BEGIN
      select Closed, DateClose into AFlag1$, ADate$ from Org_Accounts where ID = new$Service_Acc_Ref ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (AFlag1$ is null) then
      Code31$ := 0;
      new$CloseCode := :old.CloseCode - 100;

    else
      if (new$DateClose > ADate$) then
        new$DateClose := ADate$;
      END IF;
    END IF;
  END IF;
  /* ??   facialacc_cls    */

  /*  /  ??     ??   AU   */
  if (((new$Closed is null) and not(:old.Closed is null)) or
  (not(new$Closed is null) and (:old.Closed is null)))
  then
    if (new$ORG_REF is not null and  new$facialacc_cls is not null)
    then
      BEGIN
        select o.Org_Type       into vOrgType2$ from Organizations o where (o.id = new$ORG_REF)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      / ??    */
      if ((vOrgType2$  >= 10800)and(vOrgType2$  <= 10900))
      then
        if (new$Closed = 1)
        then
          /*    */
          if (new$DateClose is null) then
            CurDateToDouble(new$DateClose);
          END IF;

          update facialacc_cls set
          dateclose = new$DateClose,
          CloseCode = CloseCode + 10000
          where id = new$facialacc_cls;

        END IF;
        if (new$Closed is null)
        then
          /*    */
          update facialacc_cls set
          dateclose = null,
          CloseCode = CloseCode - 10000
          where id = new$facialacc_cls;

        END IF;
      END IF;
    END IF;
    if (new$Closed = 1) then
      new$CloseCode := 1;
    END IF;
    if (new$Closed is null) then
      new$CloseCode := 0;

    END IF;
  END IF;

  /*  /   */
  if (new$CloseCode <> :old.CloseCode) then
    DiffCode1$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */

    /*   "" */
    if (DiffCode1$ = 1) then
      Code11$ := 1;
    END IF;
    if (DiffCode1$ = 10) then
      Code21$ := 1;
    END IF;
    if (DiffCode1$ = 100) then
      Code31$ := 1;
    END IF;
    if (DiffCode1$ = 1000) then
      Code41$ := 1;
    END IF;
    if (DiffCode1$ = 10000) then
      Code5$ := 1;
    END IF;
    if (DiffCode1$ = -1) then
      Code11$ := 0;
    END IF;
    if (DiffCode1$ = -10) then
      Code21$ := 0;
    END IF;
    if (DiffCode1$ = -100) then
      Code31$ := 0;
    END IF;
    if (DiffCode1$ = -1000) then
      Code41$ := 0;
    END IF;
    if (DiffCode1$ = -10000) then
      Code5$ := 0;
    END IF;
    new$CloseCode := Code11$ + Code21$*10 + Code31$*100 + Code41$*1000 + Code5$*10000;

    if (new$CloseCode = 0) then
      new$Closed := null;
      new$DateClose := null;

    else
      new$Closed := 1;
      if (new$DateClose is null) then
        CurDateToDouble(new$DateClose);
      END IF;
      /*     ??      -  - !*/
      if (new$DateClose >= :old.DateClose) then
        new$DateClose := :old.DateClose;

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ORG_ACCOUNTS_BU_700)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (New$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_ORG_ACCOUNTS SET
    ID = new$ID,
    ORG_REF = new$ORG_REF,
    BANK_REF = new$BANK_REF,
    ACC = new$ACC,
    ACC_CLS = new$ACC_CLS,
    FINTYPE = new$FINTYPE,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    CLOSED = new$CLOSED,
    ACCDEFAULT = new$ACCDEFAULT,
    BANKDEPNUMBER = new$BANKDEPNUMBER,
    FACIALCODE = new$FACIALCODE,
    SERVICE_ORG_REF = new$SERVICE_ORG_REF,
    ACOMMENT = new$ACOMMENT,
    ISDEFAULT = new$ISDEFAULT,
    RVERSION = new$RVERSION,
    SERVICE_ACC_REF = new$SERVICE_ACC_REF,
    CLOSECODE = new$CLOSECODE,
    SERVICEACC = new$SERVICEACC,
    FACIALACC_CLS = new$FACIALACC_CLS,
    DATEOPEN = new$DATEOPEN,
    DATECLOSE = new$DATECLOSE,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_0 (TR_ORG_ACCOUNTS_AU)
-- Version 10.00.00.2
-- - - - - - - - - - - - -

  /*     ,      "  ".    */
  if (new$CloseCode <> :old.CloseCode)
  then
    if (new$CloseCode = 0) then
      update Org_Accounts set
      CloseCode = CloseCode - 100,
      RVersion = -1
      where Service_Acc_Ref = :old.ID;

    else
      update Org_Accounts set
      CloseCode = CloseCode + 100,
      DateClose = new$DateClose,
      RVersion = -1
      where Service_Acc_Ref = :old.ID;

    END IF;
  END IF;
  /*    FACIAL_CODE   */
  if (new$acc <> :old.acc) then
    update org_accounts t set
    t.facialcode = new$acc
    where
    t.service_acc_ref = new$id and t.service_org_ref = new$org_ref
    ;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_ORG_ACCOUNTS_AU_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (21, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=21) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('13.20.00', 1320, 00, ' 13.2')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
